{% load wagtailcore_tags %}<!doctype html>
<html lang="en">
  <head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.1.0/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-KyZXEAg3QhqLMpG8r+8fhAXLRk2vvoC2f3B09zVXn8CA5QIVfZOJ3BCsw2P0p/We" crossorigin="anonymous">

    <title>{{ page.title }}</title>
  </head>
  <body>
    <header class="container">
      <h1 class="mt-2">{{ page.title }}</h1>
    </header>

    <main>
      {% for block in page.body %}
        {% if block.block_type == "hero_block" %}
          {% include_block block %}
        {% else %}
          <section class="container">
            {% include_block block %}
          </section>
        {% endif %}
      {% endfor %}
    </main>
  </body>
</html>
