# Generated by Django 4.0.3 on 2022-03-31 09:48

from django.db import migrations, models
import django.db.models.deletion
import wagtail.core.blocks
import wagtail.core.fields
import wagtail.documents.blocks
import wagtail.images.blocks
import wagtail_cblocks.blocks


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0066_collection_management_permissions'),
    ]

    operations = [
        migrations.CreateModel(
            name='StandardPage',
            fields=[
                ('page_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='wagtailcore.page')),
                ('body', wagtail.core.fields.StreamField([('title_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(form_classname='title', label='Title')), ('level', wagtail.core.blocks.ChoiceBlock(choices=[(2, 'Level 2 heading'), (3, 'Level 3 heading'), (4, 'Level 4 heading'), (5, 'Level 5 heading')], label='Level'))])), ('paragraph_block', wagtail_cblocks.blocks.ParagraphBlock()), ('button_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(label='Text')), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=True))], required=True)), ('style', wagtail.core.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('primary-lg', 'Large primary')]))], default_style='primary-lg')), ('image_block', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('caption', wagtail.core.blocks.CharBlock(label='Caption', required=False)), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=False))], required=False))])), ('hero_block', wagtail.core.blocks.StructBlock([('blocks', wagtail.core.blocks.StreamBlock([('title_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(form_classname='title', label='Title')), ('level', wagtail.core.blocks.ChoiceBlock(choices=[(2, 'Level 2 heading'), (3, 'Level 3 heading'), (4, 'Level 4 heading'), (5, 'Level 5 heading')], label='Level'))])), ('paragraph_block', wagtail_cblocks.blocks.ParagraphBlock()), ('button_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(label='Text')), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=True))], required=True)), ('style', wagtail.core.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('primary-lg', 'Large primary')]))], default_style='primary-lg')), ('image_block', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('caption', wagtail.core.blocks.CharBlock(label='Caption', required=False)), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=False))], required=False))])), ('columns_block', wagtail.core.blocks.StructBlock([('columns', wagtail.core.blocks.ListBlock(wagtail.core.blocks.StreamBlock([('title_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(form_classname='title', label='Title')), ('level', wagtail.core.blocks.ChoiceBlock(choices=[(2, 'Level 2 heading'), (3, 'Level 3 heading'), (4, 'Level 4 heading'), (5, 'Level 5 heading')], label='Level'))])), ('paragraph_block', wagtail_cblocks.blocks.ParagraphBlock()), ('button_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(label='Text')), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=True))], required=True)), ('style', wagtail.core.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('primary-lg', 'Large primary')]))], default_style='primary-lg')), ('image_block', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('caption', wagtail.core.blocks.CharBlock(label='Caption', required=False)), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=False))], required=False))]))]), collapsed=True, form_classname='columns-block-list', label='Columns')), ('horizontal_align', wagtail.core.blocks.ChoiceBlock(choices=[('start', 'Left'), ('center', 'Center'), ('end', 'Right')], label='Horizontal alignment', required=False))]))], label='Content')), ('style', wagtail.core.blocks.ChoiceBlock(choices=[('centered', 'Centered'), ('responsive', 'Responsive'), ('dark', 'Dark')]))])), ('columns_block', wagtail.core.blocks.StructBlock([('columns', wagtail.core.blocks.ListBlock(wagtail.core.blocks.StreamBlock([('title_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(form_classname='title', label='Title')), ('level', wagtail.core.blocks.ChoiceBlock(choices=[(2, 'Level 2 heading'), (3, 'Level 3 heading'), (4, 'Level 4 heading'), (5, 'Level 5 heading')], label='Level'))])), ('paragraph_block', wagtail_cblocks.blocks.ParagraphBlock()), ('button_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(label='Text')), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=True))], required=True)), ('style', wagtail.core.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('primary-lg', 'Large primary')]))], default_style='primary-lg')), ('image_block', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('caption', wagtail.core.blocks.CharBlock(label='Caption', required=False)), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=False))], required=False))]))]), collapsed=True, form_classname='columns-block-list', label='Columns')), ('horizontal_align', wagtail.core.blocks.ChoiceBlock(choices=[('start', 'Left'), ('center', 'Center'), ('end', 'Right')], label='Horizontal alignment', required=False))])), ('row_columns_block', wagtail.core.blocks.StructBlock([('columns', wagtail.core.blocks.ListBlock(wagtail.core.blocks.StreamBlock([('title_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(form_classname='title', label='Title')), ('level', wagtail.core.blocks.ChoiceBlock(choices=[(2, 'Level 2 heading'), (3, 'Level 3 heading'), (4, 'Level 4 heading'), (5, 'Level 5 heading')], label='Level'))])), ('paragraph_block', wagtail_cblocks.blocks.ParagraphBlock()), ('button_block', wagtail.core.blocks.StructBlock([('text', wagtail.core.blocks.CharBlock(label='Text')), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=True))], required=True)), ('style', wagtail.core.blocks.ChoiceBlock(choices=[('primary', 'Primary'), ('secondary', 'Secondary'), ('primary-lg', 'Large primary')]))], default_style='primary-lg')), ('image_block', wagtail.core.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('caption', wagtail.core.blocks.CharBlock(label='Caption', required=False)), ('link', wagtail.core.blocks.StructBlock([('target', wagtail.core.blocks.StreamBlock([('page', wagtail.core.blocks.PageChooserBlock(icon='doc-empty-inverse', label='Page')), ('document', wagtail.documents.blocks.DocumentChooserBlock(icon='doc-full', label='Document')), ('image', wagtail.images.blocks.ImageChooserBlock(label='Image')), ('url', wagtail.core.blocks.URLBlock(label='External link')), ('anchor', wagtail.core.blocks.CharBlock(help_text='An anchor in the current page, for example: <code>#target-id</code>.', label='Anchor link'))], required=False))], required=False))]))]), collapsed=True, form_classname='columns-block-list', label='Columns')), ('horizontal_align', wagtail.core.blocks.ChoiceBlock(choices=[('start', 'Left'), ('center', 'Center'), ('end', 'Right')], label='Horizontal alignment', required=False)), ('layout', wagtail.core.blocks.ChoiceBlock(choices=[('2', '2-columns'), ('3', '3-columns'), ('4', '4-columns'), ('auto', 'natural width')]))]))])),
            ],
            options={
                'abstract': False,
            },
            bases=('wagtailcore.page',),
        ),
    ]
