#!/usr/bin/env python
import os
import sys
from pathlib import Path

sys.path.insert(0, str(Path(__file__).parent.parent.resolve()))

if __name__ == '__main__':
    os.environ.setdefault('DEBUG', '1')
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'tests.settings')

    from django.core.management import execute_from_command_line

    execute_from_command_line(sys.argv)
